1
0
forked from pool/virtualbox
virtualbox/vbox-default-os-type.diff
Larry Finger c251bb8d97 Accepting request 1004165 from home:larryr:branches:Virtualization
- Version bump to 6.1.38r86 released by Oracle September 02 2022
  This is a maintenance release. The following items were fixed and/or added:
  GUI: Improvements in Native Language Support area
  Main: OVF Export: Added support for exporting VMs containing Virtio-SCSI controllers
  Recording settings: Fixed a regression which could cause not starting the COM server (VBoxSVC) under certain circumstances (bug #21034)
  Recording: More deterministic naming for recorded files (will now overwrite old .webm files if present)
  Linux Host and Guest Additions installer: Improved check for systemd presence in the system (bug #19033)
  Linux Guest Additions: Introduced initial support for kernel 6.0
  Linux Guest Additions: Additional fixes for kernel RHEL 9.1 (bug #21065)
  Windows Guest Additions: Improvements in Drag and Drop area
  
  Fixes permission problem with /dev/vboxuser (boo#1203370)
  Fixes boo#1203306 - 6.1.38 is available
  Fixes missing firewall opening (boo#1203086)
  Fixes boo#1201720 CVE items for CVE-2022-21571, CVE-2022-21554

OBS-URL: https://build.opensuse.org/request/show/1004165
OBS-URL: https://build.opensuse.org/package/show/Virtualization/virtualbox?expand=0&rev=653
2022-09-16 17:04:36 +00:00

26 lines
1.3 KiB
Diff

Index: VirtualBox-6.1.38/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
===================================================================
--- VirtualBox-6.1.38.orig/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
+++ VirtualBox-6.1.38/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
@@ -306,15 +306,15 @@ void UINameAndSystemEditor::sltFamilyCha
if (iIndexWin7 != -1)
m_pComboType->setCurrentIndex(iIndexWin7);
}
/* Or select Oracle Linux item for Linux family as default: */
else if (m_strFamilyId == "Linux")
{
- QString strDefaultID = "Oracle";
+ QString strDefaultID = "openSUSE";
if (ARCH_BITS == 64 && m_fSupportsHWVirtEx && m_fSupportsLongMode)
strDefaultID += "_64";
- const int iIndexUbuntu = m_pComboType->findData(strDefaultID, TypeID);
- if (iIndexUbuntu != -1)
- m_pComboType->setCurrentIndex(iIndexUbuntu);
+ const int iIndexOpenSUSE = m_pComboType->findData(strDefaultID, TypeID);
+ if (iIndexOpenSUSE != -1)
+ m_pComboType->setCurrentIndex(iIndexOpenSUSE);
}
/* Else simply select the first one present: */
else
@@ -306,15 +306,15 @@ void UINameAndSystemEditor::sltFamilyCha
m_pComboType->setCurrentIndex(iIndexWin7);
}
- /* Or select Oracle Linux item for Linux family as default: */
+ /* Or select openSUSE item for Linux family as default: */
else if (m_strFamilyId == "Linux")
{